@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef __MENU_UTIL_H__
@@ -26,10 +26,7 @@
 
 #include "menu-layout.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
+G_BEGIN_DECLS
 
 
 #ifdef G_ENABLE_DEBUG
@@ -52,8 +49,6 @@ extern "C" {
 
 #endif /* G_ENABLE_DEBUG */
 
-#ifdef __cplusplus
-}
-#endif
+G_END_DECLS
 
 #endif /* __MENU_UTIL_H__ */
